# Test fixture: generic naming patterns

def process(data, val):
    result = data + val
    temp = result * 2
    return temp

def calculate_tax(income, tax_rate):
    """Good naming example."""
    tax_amount = income * tax_rate
    return tax_amount

def transform(item, info):
    output = item + info
    return output
